summaryrefslogtreecommitdiffstats
path: root/video/hwdec.h
diff options
context:
space:
mode:
Diffstat (limited to 'video/hwdec.h')
-rw-r--r--video/hwdec.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/video/hwdec.h b/video/hwdec.h
index 761b8d699b..c9eb8e6a95 100644
--- a/video/hwdec.h
+++ b/video/hwdec.h
@@ -1,9 +1,11 @@
#ifndef MP_HWDEC_H_
#define MP_HWDEC_H_
+#include "options/m_option.h"
+
struct mp_image_pool;
// keep in sync with --hwdec option
enum hwdec_type {
HWDEC_AUTO = -1,
HWDEC_NONE = 0,
@@ -15,6 +17,9 @@ enum hwdec_type {
HWDEC_RPI = 7,
};
+// hwdec_type names (options.c)
+extern const struct m_opt_choice_alternatives mp_hwdec_names[];
+
struct mp_hwdec_ctx {
enum hwdec_type type;
@@ -1,9 +1,11 @@
struct mp_image_pool;
-// keep in sync with --hwdec option
+// keep in sync with --hwdec option (see mp_hwdec_names)
enum hwdec_type {
HWDEC_AUTO = -1,